@@ -10,13 +10,15 @@ def filterFields(self, *predicates, **values):
             this.isMegamanicEditable():
         for field in result:
             try:
-                if field.get(self):
+                if field.getAccessor(self)() !=\
+                        field.default:
                     result2.append(field)
             except:
                 # Something went wrong, but the
                 # field was available so lets
                 # juts pass it along
                 result2.append(field)
+#        import pdb; pdb.set_trace()
         return result2
     return result
 
