@@ -8,10 +8,13 @@
 
 old = old.replace('name="' + fieldNameNormal + '"',
                    'name="' + fieldName + '"' + """ onfocus="clear_if_default('%s');" """ % fieldName)
-# For textareas/rich fields
+# For textareas/rich fields and :lines
 old = old.replace('name="' + fieldNameNormal + '_text_format"',
                    'name="' + fieldName + '_text_format"')
 
+old = old.replace('name="' + fieldNameNormal + '_keywords:lines"',
+                   'name="' + fieldName + '_keywords:lines"')
+
 # Heh
 new = old
 
