@@ -1,4 +1,4 @@
-from Products.Archetypes.Widget import PasswordWidget
+from Products.Archetypes.Widget import PasswordWidget, LinesWidget
 from interfaces import MegamanicEditableTemplateObject
 
 def setup(klass):
@@ -6,6 +6,8 @@ def setup(klass):
     enable_postback(schema)
     if MegamanicEditableTemplateObject.implementedBy(klass) and schema.has_key('subject'):
         schema.changeSchemataForField('subject', 'default')
+    schema['subject'].widget = LinesWidget
+    schema['subject']._widgetLayer()
 
 def enable_postback(schema):
     """Enables postback for all schema fields, except password."""
